@@ -126,7 +126,7 @@ QDeclarativeDebugServerConnection *QDeclarativeDebugServerPrivate::loadConnectio
     QStringList pluginCandidates;
     const QStringList paths = QCoreApplication::libraryPaths();
     foreach (const QString &libPath, paths) {
-        const QDir dir(libPath + QLatin1String("/qmltooling"));
+        const QDir dir(libPath + QLatin1String("/qml1tooling"));
         if (dir.exists()) {
             QStringList plugins(dir.entryList(QDir::Files));
             foreach (const QString &pluginPath, plugins) {
@@ -266,7 +266,12 @@ void QDeclarativeDebugServer::receiveMessage(const QByteArray &message)
         QByteArray helloAnswer;
         {
             QDataStream out(&helloAnswer, QIODevice::WriteOnly);
-            out << QString(QLatin1String("QDeclarativeDebugClient")) << 0 << protocolVersion << d->plugins.keys();
+            QList<float> fakeVersions;
+            for (int i = 0; i < d->plugins.size(); ++i)
+                fakeVersions << 1.0;
+            out << QString(QLatin1String("QDeclarativeDebugClient")) << 0
+                << protocolVersion << d->plugins.keys()
+                << fakeVersions << QDataStream().version();
         }
         d->connection->send(QList<QByteArray>() << helloAnswer);
 
