@@ -56,8 +56,6 @@
 // We mean it.
 //
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -83,6 +81,4 @@ Q_DECLARE_INTERFACE(QDeclarativeDebugServerConnection, QDeclarativeDebugServerCo
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QDECLARATIVEDEBUGSERVERCONNECTION_H
