@@ -62,8 +62,6 @@ class QScriptValue;
 class QDeclarativeEngine;
 QT_END_NAMESPACE
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -225,6 +223,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QJSDEBUGGERAGENT_P_H
