@@ -128,8 +128,8 @@ public:
       componentComplete(true), keepMouse(false),
       smooth(false), transformOriginDirty(true), doneEventPreHandler(false),
       inheritedLayoutMirror(false), effectiveLayoutMirror(false), isMirrorImplicit(true),
-      inheritMirrorFromParent(false), inheritMirrorFromItem(false), keyHandler(0),
-      mWidth(0), mHeight(0), mImplicitWidth(0), mImplicitHeight(0), attachedLayoutDirection(0), hadSubFocusItem(false)
+      inheritMirrorFromParent(false), inheritMirrorFromItem(false), hadFocus(false), hadActiveFocus(false), keyHandler(0),
+      mWidth(0), mHeight(0), mImplicitWidth(0), mImplicitHeight(0), attachedLayoutDirection(0)
     {
         QGraphicsItemPrivate::acceptedMouseButtons = 0;
         isDeclarativeItem = 1;
@@ -289,6 +289,8 @@ public:
     bool isMirrorImplicit:1;
     bool inheritMirrorFromParent:1;
     bool inheritMirrorFromItem:1;
+    bool hadFocus:1;
+    bool hadActiveFocus:1;
 
     QDeclarativeItemKeyFilter *keyHandler;
 
@@ -299,7 +301,6 @@ public:
 
     QDeclarativeLayoutMirroringAttached* attachedLayoutDirection;
 
-    bool hadSubFocusItem;
 
     QPointF computeTransformOrigin() const;
 
@@ -311,23 +312,15 @@ public:
         q->geometryChanged(QRectF(this->pos.x(), this->pos.y(), mWidth, mHeight), oldGeometry);
     }
 
-    // Reimplemented from QGraphicsItemPrivate
-    virtual void subFocusItemChange()
-    {
-        bool hasSubFocusItem = subFocusItem != 0;
-        if (((flags & QGraphicsItem::ItemIsFocusScope) || !parent) && hasSubFocusItem != hadSubFocusItem)
-            emit q_func()->activeFocusChanged(hasSubFocusItem);
-        //see also QDeclarativeItemPrivate::focusChanged
-        hadSubFocusItem = hasSubFocusItem;
-    }
-
     // Reimplemented from QGraphicsItemPrivate
     virtual void focusScopeItemChange(bool isSubFocusItem)
     {
-        emit q_func()->focusChanged(isSubFocusItem);
+        if (hadFocus != isSubFocusItem) {
+            hadFocus = isSubFocusItem;
+            emit q_func()->focusChanged(isSubFocusItem);
+        }
     }
 
-
     // Reimplemented from QGraphicsItemPrivate
     virtual void siblingOrderChange()
     {
