@@ -530,39 +530,35 @@ void QDeclarativeMouseArea::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
             curLocalPos = event->scenePos();
         }
 
-        const int dragThreshold = QApplication::startDragDistance();
-        qreal dx = qAbs(curLocalPos.x() - startLocalPos.x());
-        qreal dy = qAbs(curLocalPos.y() - startLocalPos.y());
-
         if (keepMouseGrab() && d->stealMouse)
             d->drag->setActive(true);
 
         bool dragX = drag()->axis() & QDeclarativeDrag::XAxis;
         bool dragY = drag()->axis() & QDeclarativeDrag::YAxis;
 
-        if (dragX && d->drag->active()) {
-            qreal x = (curLocalPos.x() - startLocalPos.x()) + d->startX;
-            if (x < drag()->xmin())
-                x = drag()->xmin();
-            else if (x > drag()->xmax())
-                x = drag()->xmax();
-            drag()->target()->setX(x);
-        }
-        if (dragY && d->drag->active()) {
-            qreal y = (curLocalPos.y() - startLocalPos.y()) + d->startY;
-            if (y < drag()->ymin())
-                y = drag()->ymin();
-            else if (y > drag()->ymax())
-                y = drag()->ymax();
-            drag()->target()->setY(y);
+        const qreal x = dragX
+                ? qBound(d->drag->xmin(), d->startX + curLocalPos.x() - startLocalPos.x(), d->drag->xmax())
+                : d->startX;
+        const qreal y = dragY
+                ? qBound(d->drag->ymin(), d->startY + curLocalPos.y() - startLocalPos.y(), d->drag->ymax())
+                : d->startY;
+
+        if (d->drag->active()) {
+            if (dragX && dragY)
+                d->drag->target()->setPos(x, y);
+            else if (dragX)
+                d->drag->target()->setX(x);
+            else if (dragY)
+                d->drag->target()->setY(y);
         }
 
         if (!keepMouseGrab()) {
-            if ((!dragY && dy < dragThreshold && dragX && dx > dragThreshold)
-                || (!dragX && dx < dragThreshold && dragY && dy > dragThreshold)
-                || (dragX && dragY && (dx > dragThreshold || dy > dragThreshold))) {
+            const int dragThreshold = QApplication::startDragDistance();
+
+            if (qAbs(x - d->startX) > dragThreshold || qAbs(y - d->startY) > dragThreshold) {
                 setKeepMouseGrab(true);
                 d->stealMouse = true;
+                d->startScene = event->scenePos();
             }
         }
 
