@@ -49,8 +49,6 @@
 #include <QtCore/qmetatype.h>
 #include <QtCore/qvariant.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -110,6 +108,4 @@ QT_END_NAMESPACE
 
 Q_DECLARE_METATYPE(QList<QObject*>)
 
-QT_END_HEADER
-
 #endif // QDECLARATIVECONTEXT_H
