@@ -556,14 +556,10 @@ void QDeclarativePrivate::qdeclarativeelement_destructor(QObject *o)
 
 void QDeclarativeData::destroyed(QAbstractDeclarativeData *d, QObject *o)
 {
-    static_cast<QDeclarativeData *>(d)->destroyed(o);
-}
-
-void QDeclarativeData::parentChanged(QAbstractDeclarativeData *d, QObject *o, QObject *p)
-{
-    Q_UNUSED(d)
-    Q_UNUSED(o)
-    Q_UNUSED(p)
+    QDeclarativeData *ddata = static_cast<QDeclarativeData *>(d);
+    if (!ddata->ownedByQml1)
+        return;
+    ddata->destroyed(o);
 }
 
 void QDeclarativeEnginePrivate::init()
@@ -1020,6 +1016,8 @@ QDeclarativeEngine::ObjectOwnership QDeclarativeEngine::objectOwnership(QObject
         return ddata->indestructible?CppOwnership:JavaScriptOwnership;
 }
 
+namespace QtDeclarative {
+
 void qmlExecuteDeferred(QObject *object)
 {
     QDeclarativeData *data = QDeclarativeData::get(object);
@@ -1088,9 +1086,45 @@ QObject *qmlAttachedPropertiesObject(int *idCache, const QObject *object,
     if (*idCache == -1 || !object)
         return 0;
 
-    return qmlAttachedPropertiesObjectById(*idCache, object, create);
+    return QtDeclarative::qmlAttachedPropertiesObjectById(*idCache, object, create);
 }
 
+} // namespace QtDeclarative
+
+#if QT_DEPRECATED_SINCE(5, 1)
+
+// Also define symbols outside namespace to keep binary compatibility with 5.0
+
+Q_DECLARATIVE_EXPORT void qmlExecuteDeferred(QObject *obj)
+{
+    QtDeclarative::qmlExecuteDeferred(obj);
+}
+
+Q_DECLARATIVE_EXPORT QDeclarativeContext *qmlContext(const QObject *obj)
+{
+    return QtDeclarative::qmlContext(obj);
+}
+
+Q_DECLARATIVE_EXPORT QDeclarativeEngine *qmlEngine(const QObject *obj)
+{
+    return QtDeclarative::qmlEngine(obj);
+}
+
+Q_DECLARATIVE_EXPORT QObject *qmlAttachedPropertiesObjectById(int id, const QObject * obj,
+                                                              bool create)
+{
+    return QtDeclarative::qmlAttachedPropertiesObjectById(id, obj, create);
+}
+
+Q_DECLARATIVE_EXPORT QObject *qmlAttachedPropertiesObject(int *idCache, const QObject *object,
+                                                          const QMetaObject *attachedMetaObject,
+                                                          bool create)
+{
+    return QtDeclarative::qmlAttachedPropertiesObject(idCache, object, attachedMetaObject, create);
+}
+
+#endif // QT_DEPRECATED_SINCE(5, 1)
+
 QDeclarativeDebuggingEnabler::QDeclarativeDebuggingEnabler()
 {
 #ifndef QDECLARATIVE_NO_DEBUG_PROTOCOL
