@@ -45,8 +45,6 @@
 #include <QtDeclarative/qtdeclarativeglobal.h>
 #include <QtCore/qobject.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -66,6 +64,4 @@ Q_DECLARE_INTERFACE(QDeclarativeExtensionInterface, QDeclarativeExtensionInterfa
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QDECLARATIVEEXTENSIONINTERFACE_H
