@@ -45,8 +45,6 @@
 #include <QtCore/qvector.h>
 #include <QtCore/qhash.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QObject;
@@ -71,6 +69,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QDECLARATIVEFASTPROPERTIES_P_H
