@@ -52,6 +52,8 @@
 #include <private/qdeclarativetypenamecache_p.h>
 #include <private/qdeclarativeengine_p.h>
 
+#include <algorithm>
+
 QT_BEGIN_NAMESPACE
 
 DEFINE_BOOL_CONFIG_OPTION(qmlImportTrace, QML_IMPORT_TRACE)
@@ -400,7 +402,7 @@ QString QDeclarativeImportsPrivate::resolvedUri(const QString &dir_arg, QDeclara
         dir.chop(1);
 
     QStringList paths = database->fileImportPath;
-    qSort(paths.begin(), paths.end(), greaterThan); // Ensure subdirs preceed their parents.
+    std::sort(paths.begin(), paths.end(), greaterThan); // Ensure subdirs preceed their parents.
 
     QString stableRelativePath = dir;
     foreach(const QString &path, paths) {
@@ -441,6 +443,13 @@ bool QDeclarativeImportsPrivate::add(const QDeclarativeDirComponents &qmldircomp
             set.insert(prefix,(s=new QDeclarativeImportedNamespace));
     }
 
+    bool appendInstead = false;
+    if (importType == QDeclarativeScriptParser::Import::Implicit) {
+        //Treat same as a File import, but lower precedence
+        appendInstead = true;
+        importType = QDeclarativeScriptParser::Import::File;
+    }
+
     QString url = uri;
     bool versionFound = false;
     if (importType == QDeclarativeScriptParser::Import::Library) {
@@ -511,6 +520,9 @@ bool QDeclarativeImportsPrivate::add(const QDeclarativeDirComponents &qmldircomp
         if (QDeclarativeMetaType::isModule(uri.toUtf8(), vmaj, vmin))
             versionFound = true;
 
+        //Load any type->file mappings registered for this uri
+        qmldircomponents << QDeclarativeMetaType::qmlComponents(uri.toUtf8(), vmaj, vmin);
+
         if (!versionFound && qmldircomponents.isEmpty()) {
             if (errorString) {
                 bool anyversion = QDeclarativeMetaType::isModule(uri.toUtf8(), -1, -1);
@@ -588,12 +600,21 @@ bool QDeclarativeImportsPrivate::add(const QDeclarativeDirComponents &qmldircomp
         }
     }
 
-    s->uris.prepend(uri);
-    s->urls.prepend(url);
-    s->majversions.prepend(vmaj);
-    s->minversions.prepend(vmin);
-    s->isLibrary.prepend(importType == QDeclarativeScriptParser::Import::Library);
-    s->qmlDirComponents.prepend(qmldircomponents);
+    if (appendInstead) {
+        s->uris.append(uri);
+        s->urls.append(url);
+        s->majversions.append(vmaj);
+        s->minversions.append(vmin);
+        s->isLibrary.append(importType == QDeclarativeScriptParser::Import::Library);
+        s->qmlDirComponents.append(qmldircomponents);
+    } else {
+        s->uris.prepend(uri);
+        s->urls.prepend(url);
+        s->majversions.prepend(vmaj);
+        s->minversions.prepend(vmin);
+        s->isLibrary.prepend(importType == QDeclarativeScriptParser::Import::Library);
+        s->qmlDirComponents.prepend(qmldircomponents);
+    }
     return true;
 }
 
