@@ -46,8 +46,6 @@
 #include <QtCore/qlist.h>
 #include <QtCore/qvariant.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -147,6 +145,4 @@ QT_END_NAMESPACE
 
 Q_DECLARE_METATYPE(QDeclarativeListReference)
 
-QT_END_HEADER
-
 #endif // QDECLARATIVELIST_H
