@@ -47,8 +47,6 @@
 #include <QtCore/qshareddata.h>
 #include <QtCore/qmetatype.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -82,7 +80,5 @@ QT_END_NAMESPACE
 
 Q_DECLARE_METATYPE(QDeclarativeScriptString)
 
-QT_END_HEADER
-
 #endif // QDECLARATIVESCRIPTSTRING_H
 
