@@ -55,8 +55,6 @@
 #include <QtCore/QAbstractAnimation>
 #include <QtGui/qcolor.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -534,6 +532,4 @@ QML_DECLARE_TYPE(QDeclarativeRotationAnimation)
 QML_DECLARE_TYPE(QDeclarativeParentAnimation)
 QML_DECLARE_TYPE(QDeclarativeAnchorAnimation)
 
-QT_END_HEADER
-
 #endif // QDECLARATIVEANIMATION_H
