@@ -46,8 +46,6 @@
 #include <qdeclarative.h>
 #include <private/qtdeclarativeglobal_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -81,6 +79,4 @@ QT_END_NAMESPACE
 
 QML_DECLARE_TYPE(QDeclarativeApplication)
 
-QT_END_HEADER
-
 #endif // QDECLARATIVEAPPLICATION_P_H
