@@ -48,8 +48,6 @@
 #include <QtCore/qsharedpointer.h>
 #include <private/qtdeclarativeglobal_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -205,6 +203,4 @@ QT_END_NAMESPACE
 QML_DECLARE_TYPE(QDeclarativeStateOperation)
 QML_DECLARE_TYPE(QDeclarativeState)
 
-QT_END_HEADER
-
 #endif // QDECLARATIVESTATE_H
