@@ -50,6 +50,8 @@
 #include <QEasingCurve>
 #include <QTime>
 
+#include <algorithm>
+
 QT_BEGIN_NAMESPACE
 
 struct Update {
@@ -807,7 +809,7 @@ int QDeclarativeTimeLinePrivate::advance(int t)
         length -= qMin(length, advanceTime);
         syncPoint -= advanceTime;
 
-        qSort(updates.begin(), updates.end());
+        std::sort(updates.begin(), updates.end());
         updateQueue = &updates;
         for (int ii = 0; ii < updates.count(); ++ii) {
             const Update &v = updates.at(ii).second;
