@@ -49,8 +49,6 @@
 
 #ifndef QT_NO_DIRMODEL
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -153,8 +151,6 @@ QT_END_NAMESPACE
 QML_DECLARE_TYPE(QDeclarativeFolderListModel)
 //![qml decl]
 
-QT_END_HEADER
-
 #endif // QT_NO_DIRMODEL
 
 #endif // QDECLARATIVEFOLDERLISTMODEL_H
