@@ -44,8 +44,6 @@
 
 #include <QGLFramebufferObject>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class ShaderEffectBuffer : public QGLFramebufferObject
@@ -55,8 +53,6 @@ public:
     ~ShaderEffectBuffer();
 };
 
-QT_END_HEADER
-
 QT_END_NAMESPACE
 
 #endif // SHADEREFFECTBUFFER_H
