@@ -47,8 +47,6 @@
 #include "shadereffectsource.h"
 #include "scenegraph/qsggeometry.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QGLFramebufferObject;
@@ -148,8 +146,6 @@ private:
     bool m_defaultVertexShader : 1;
 };
 
-QT_END_HEADER
-
 QT_END_NAMESPACE
 
 #endif // SHADEREFFECTITEM_H
