@@ -63,18 +63,18 @@ void tst_qdeclarativeerror::url()
 
     QCOMPARE(error.url(), QUrl());
 
-    error.setUrl(QUrl("http://www.nokia.com/main.qml"));
+    error.setUrl(QUrl("http://www.qt-project.org/main.qml"));
 
-    QCOMPARE(error.url(), QUrl("http://www.nokia.com/main.qml"));
+    QCOMPARE(error.url(), QUrl("http://www.qt-project.org/main.qml"));
 
     QDeclarativeError error2 = error;
 
-    QCOMPARE(error2.url(), QUrl("http://www.nokia.com/main.qml"));
+    QCOMPARE(error2.url(), QUrl("http://www.qt-project.org/main.qml"));
 
-    error.setUrl(QUrl("http://qt.nokia.com/main.qml"));
+    error.setUrl(QUrl("http://www.qt-project.org/main.qml"));
 
-    QCOMPARE(error.url(), QUrl("http://qt.nokia.com/main.qml"));
-    QCOMPARE(error2.url(), QUrl("http://www.nokia.com/main.qml"));
+    QCOMPARE(error.url(), QUrl("http://www.qt-project.org/main.qml"));
+    QCOMPARE(error2.url(), QUrl("http://www.qt-project.org/main.qml"));
 }
 
 void tst_qdeclarativeerror::description()
@@ -141,28 +141,28 @@ void tst_qdeclarativeerror::toString()
 {
     {
         QDeclarativeError error;
-        error.setUrl(QUrl("http://www.nokia.com/main.qml"));
+        error.setUrl(QUrl("http://www.qt-project.org/main.qml"));
         error.setDescription("An Error");
         error.setLine(92);
         error.setColumn(13);
 
-        QCOMPARE(error.toString(), QString("http://www.nokia.com/main.qml:92:13: An Error"));
+        QCOMPARE(error.toString(), QString("http://www.qt-project.org/main.qml:92:13: An Error"));
     }
 
     {
         QDeclarativeError error;
-        error.setUrl(QUrl("http://www.nokia.com/main.qml"));
+        error.setUrl(QUrl("http://www.qt-project.org/main.qml"));
         error.setDescription("An Error");
         error.setLine(92);
 
-        QCOMPARE(error.toString(), QString("http://www.nokia.com/main.qml:92: An Error"));
+        QCOMPARE(error.toString(), QString("http://www.qt-project.org/main.qml:92: An Error"));
     }
 }
 
 void tst_qdeclarativeerror::copy()
 {
     QDeclarativeError error;
-    error.setUrl(QUrl("http://www.nokia.com/main.qml"));
+    error.setUrl(QUrl("http://www.qt-project.org/main.qml"));
     error.setDescription("An Error");
     error.setLine(92);
     error.setColumn(13);
@@ -171,22 +171,22 @@ void tst_qdeclarativeerror::copy()
     QDeclarativeError error3;
     error3 = error;
 
-    error.setUrl(QUrl("http://qt.nokia.com/main.qml"));
+    error.setUrl(QUrl("http://www.qt-project.org/main.qml"));
     error.setDescription("Another Error");
     error.setLine(2);
     error.setColumn(33);
 
-    QCOMPARE(error.url(), QUrl("http://qt.nokia.com/main.qml"));
+    QCOMPARE(error.url(), QUrl("http://www.qt-project.org/main.qml"));
     QCOMPARE(error.description(), QString("Another Error"));
     QCOMPARE(error.line(), 2);
     QCOMPARE(error.column(), 33);
 
-    QCOMPARE(error2.url(), QUrl("http://www.nokia.com/main.qml"));
+    QCOMPARE(error2.url(), QUrl("http://www.qt-project.org/main.qml"));
     QCOMPARE(error2.description(), QString("An Error"));
     QCOMPARE(error2.line(), 92);
     QCOMPARE(error2.column(), 13);
 
-    QCOMPARE(error3.url(), QUrl("http://www.nokia.com/main.qml"));
+    QCOMPARE(error3.url(), QUrl("http://www.qt-project.org/main.qml"));
     QCOMPARE(error3.description(), QString("An Error"));
     QCOMPARE(error3.line(), 92);
     QCOMPARE(error3.column(), 13);
@@ -197,12 +197,12 @@ void tst_qdeclarativeerror::debug()
 {
     {
         QDeclarativeError error;
-        error.setUrl(QUrl("http://www.nokia.com/main.qml"));
+        error.setUrl(QUrl("http://www.qt-project.org/main.qml"));
         error.setDescription("An Error");
         error.setLine(92);
         error.setColumn(13);
 
-        QTest::ignoreMessage(QtWarningMsg, "http://www.nokia.com/main.qml:92:13: An Error ");
+        QTest::ignoreMessage(QtWarningMsg, "http://www.qt-project.org/main.qml:92:13: An Error ");
         qWarning() << error;
     }
 
